@@ -17,7 +17,15 @@ limitations under the License.
 import warnings
 
 import numpy as np
+import pytest
 import scipy.sparse as sp
+from hypothesis import assume, given
+from hypothesis.extra.numpy import (
+    arrays,
+    basic_indices,
+    broadcastable_shapes,
+    integer_array_indices,
+)
 
 import cvxpy as cp
 import cvxpy.interface.matrix_utilities as intf
@@ -70,31 +78,13 @@ class TestExpressions(BaseTest):
 
         self.assertEqual(repr(self.x), "Variable((2,), x)")
         self.assertEqual(repr(self.A), "Variable((2, 2), A)")
-        self.assertEqual(repr(cp.Variable(name='x', nonneg=True)), "Variable((), x, nonneg=True)")
+        self.assertEqual(repr(cp.Variable(name='x', nonneg=True)),
+                         "Variable((), x, nonneg=True)")
         self.assertTrue(repr(cp.Variable()).startswith("Variable((), var"))
 
         # Test shape provided as list instead of tuple
         self.assertEqual(cp.Variable(shape=[2], integer=True).shape, (2,))
 
-        # # Scalar variable
-        # coeff = self.a.coefficients()
-        # self.assertEqual(coeff[self.a.id], [1])
-
-        # # Vector variable.
-        # coeffs = x.coefficients()
-        # self.assertItemsEqual(coeffs.keys(), [x.id])
-        # vec = coeffs[x.id][0]
-        # self.assertEqual(vec.shape, (2,2))
-        # self.assertEqual(vec[0,0], 1)
-
-        # # Matrix variable.
-        # coeffs = self.A.coefficients()
-        # self.assertItemsEqual(coeffs.keys(), [self.A.id])
-        # self.assertEqual(len(coeffs[self.A.id]), 2) or 0 in self.shape
-        # mat = coeffs[self.A.id][1]
-        # self.assertEqual(mat.shape, (2,4))
-        # self.assertEqual(mat[0,2], 1)
-
         with self.assertRaises(Exception) as cm:
             Variable((2, 2), diag=True, symmetric=True)
         self.assertEqual(str(cm.exception),
@@ -779,13 +769,6 @@ class TestExpressions(BaseTest):
             q = self.A .__matmul__(self.B)
             self.assertTrue(q.is_quadratic())
 
-        # # Nonaffine times nonconstant raises error
-        # with warnings.catch_warnings():
-        #     warnings.simplefilter("ignore")
-        #     with self.assertRaises(Exception) as cm:
-        #         (self.A.__matmul__(self.B).__matmul__(self.A))
-        #     self.assertEqual(str(cm.exception), "Cannot multiply UNKNOWN and AFFINE.")
-
         # Constant expressions
         T = Constant([[1, 2, 3], [3, 5, 5]])
         exp = (T + T) .__matmul__(self.B)
@@ -833,7 +816,7 @@ class TestExpressions(BaseTest):
             (self.x/[2, 2, 3])
         print(cm.exception)
         self.assertRegex(str(cm.exception),
-                         "Incompatible shapes for division.*")
+                         "Incompatible shapes for division")
 
         c = Constant([3.0, 4.0, 12.0])
         self.assertItemsAlmostEqual(
@@ -870,12 +853,6 @@ class TestExpressions(BaseTest):
         A = np.ones((3, 3)) / c
         self.assertItemsAlmostEqual(A, expr.value)
 
-        with self.assertRaises(Exception) as cm:
-            (x/c[:, 0])
-        print(cm.exception)
-        self.assertRegex(str(cm.exception),
-                         "Incompatible shapes for division.*")
-
     # Test the NegExpression class.
     def test_neg_expression(self) -> None:
         # Vectors
@@ -1022,6 +999,15 @@ class TestExpressions(BaseTest):
         self.assertEqual(exp.curvature, s.AFFINE)
         self.assertEqual(exp.shape, (1,))
 
+    def test_special_idx_str_repr(self) -> None:
+        idx = [i for i in range(178)]
+        exp = cp.Variable((200, 10), name="exp")[idx, 6]
+        self.assertEqual("exp[[0, 1, 2, ..., 175, 176, 177], 6]", str(exp))
+
+        idx = [i for i in range(5)]
+        exp = cp.Variable((10, 10), name="exp")[idx, 2:5]
+        self.assertEqual("exp[[0, 1, 2, 3, 4], 2:5]", str(exp))
+
     def test_none_idx(self) -> None:
         """Test None as index.
         """
@@ -1316,10 +1302,6 @@ class TestExpressions(BaseTest):
 
         col_scale = Variable(n)
 
-        with self.assertRaises(ValueError) as cm:
-            cp.multiply(A, col_scale)
-        self.assertEqual(str(cm.exception), "Cannot broadcast dimensions  (3, 4) (4,)")
-
         col_scale = Variable([1, n])
         C = cp.multiply(A, col_scale)
         self.assertEqual(C.shape, (m, n))
@@ -1348,10 +1330,6 @@ class TestExpressions(BaseTest):
 
         col_scale = Variable(n)
 
-        with self.assertRaises(ValueError) as cm:
-            A + col_scale
-        self.assertEqual(str(cm.exception), "Cannot broadcast dimensions  (3, 4) (4,)")
-
         col_scale = Variable([1, n])
         C = A + col_scale
         self.assertEqual(C.shape, (m, n))
@@ -1532,3 +1510,279 @@ class TestExpressions(BaseTest):
         expr = hermitian_wrap(U)
         assert expr.is_hermitian()
 
+    def test_expr_does_not_support_cpp_warning(self):
+        from cvxpy.atoms.affine.sum import Sum
+
+        class SumNotSupportedInCPP(Sum):
+            def _supports_cpp(self):
+                return False
+
+        x = Variable(2)
+        prob = Problem(Minimize(0), [SumNotSupportedInCPP(x) == 1])
+
+        with pytest.warns(
+            UserWarning,
+            match="The problem includes expressions that don't support "
+            "CPP backend. Defaulting to the SCIPY backend "
+            "for canonicalization.",
+        ):
+            prob.solve()
+
+
+    def test_expr_does_not_support_cpp_error(self):
+        from cvxpy.atoms.affine.sum import Sum
+
+        class SumNotSupportedInCPP(Sum):
+            def _supports_cpp(self):
+                return False
+
+        x = Variable(2)
+        prob = Problem(Minimize(0), [SumNotSupportedInCPP(x) == 1])
+
+        with pytest.raises(
+            ValueError,
+            match="The CPP backend cannot be used with problems "
+            "that have expressions which do not support it",
+        ):
+            prob.solve(canon_backend=cp.CPP_CANON_BACKEND)
+
+
+class TestND_Expressions():
+
+    @pytest.fixture(autouse=True)
+    def setup(self) -> None:
+        self.x = Variable((2,2,2), name='x')
+        self.target = (1+np.arange(8)).reshape(2,2,2)
+        self.obj = cp.Minimize(0)
+
+    def test_nd_variable(self) -> None:
+        prob = cp.Problem(self.obj, [self.x == self.target])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(self.x.value, self.target)
+
+    def test_nd_variable_warning(self) -> None:
+        prob = cp.Problem(self.obj, [self.x == self.target])
+        warning_str = "The problem has an expression with dimension greater than 2. " \
+                    "Defaulting to the SCIPY backend for canonicalization."
+        with pytest.warns(UserWarning, match=warning_str):
+            prob.solve()
+
+    def test_nd_variable_value_error(self) -> None:
+        prob = cp.Problem(self.obj, [self.x == self.target])
+        error_str = "Only the SCIPY and NUMPY backends are supported " \
+                    "for problems with expressions of dimension greater than 2."
+        with pytest.raises(ValueError, match=error_str):
+            prob.solve(canon_backend=cp.CPP_CANON_BACKEND)
+
+    def test_nd_mul_elem(self) -> None:
+        expr = cp.multiply(self.x, 3)
+        prob = cp.Problem(self.obj, [expr == self.target])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, self.target)
+
+    def test_nd_div(self) -> None:
+        expr = self.x / self.target
+        prob = cp.Problem(self.obj, [expr == self.target])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, self.target)
+
+    def test_nd_vstack(self) -> None:
+        x = Variable((1, 2, 2))
+        z = Variable((1, 2, 2))
+        expr = cp.vstack([x,z])
+        prob = cp.Problem(self.obj, [expr == self.target])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, self.target)
+
+    def test_nd_concatenate(self) -> None:
+        x = cp.Variable((1, 2, 2))
+        z = cp.Variable((1, 2, 2))
+        expr = cp.concatenate([x,z], axis = 0)
+        prob = cp.Problem(self.obj, [expr == self.target])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, self.target)
+
+    def test_nd_sum_expr(self) -> None:
+        x = [cp.Variable((2,2,2)) for _ in range(10)]
+        expr = sum(x)
+        prob = cp.Problem(self.obj, [expr == self.target])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, self.target)
+
+    @pytest.mark.parametrize("axis", [(0),(1),(2),((0,1)),((0,2)),((2,1))])
+    def test_nd_sum(self, axis) -> None:
+        expr = cp.sum(self.x, axis=axis, keepdims=True)
+        y = self.target.sum(axis=axis, keepdims=True)
+        prob = cp.Problem(self.obj, [expr == y])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, y)
+
+    @pytest.mark.parametrize("axis", [(0),(1),(2),((0,1)),((0,2)),((2,1))])
+    def test_nd_parametrized_sum(self, axis) -> None:
+        param = cp.Parameter((2,2,2))
+        param.value = np.arange(8).reshape(2,2,2)
+        expr = cp.multiply(self.x, param).sum(axis=axis)
+        target = self.target.sum(axis=axis)
+        prob = cp.Problem(self.obj, [expr == target])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, target)
+
+    @pytest.mark.parametrize("axis", [(0,2,4,5),((4,5)),((0,2,3,1)),((5,3,1)), ((0,1,2,5))])
+    def test_nd_big_sum(self, axis) -> None:
+        in_shape = (6,5,4,3,2,1)
+        expr = cp.Variable(shape=in_shape).sum(axis=axis, keepdims=True)
+        y = np.ones(in_shape).sum(axis=axis, keepdims=True)
+        prob = cp.Problem(self.obj, [expr == y])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, y)
+
+    @given(integer_array_indices(shape=(2,2,2)))
+    def test_nd_integer_index(self, s) -> None:
+        expr = self.x[s]
+        y = self.target[s]
+        prob = cp.Problem(self.obj, [expr == y])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, y)
+
+    @given(axis=basic_indices(shape=(2,2,2), allow_newaxis=True))
+    def test_nd_basic_index(self, axis) -> None:
+        # Skip examples with 0-d output. TODO allow 0-d expressions in cvxpy.
+        def is_zero_dim_output(axis):
+            return 0 in self.target[axis].shape
+
+        assume(is_zero_dim_output(axis) is False)
+        expr = self.x[axis]
+        y = self.target[axis]
+        prob = cp.Problem(self.obj, [expr == y])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, y)
+
+    @given(axis=integer_array_indices(shape=(6,5,4,3,2,1)))
+    def test_nd_big_index(self, axis) -> None:
+        in_shape = (6,5,4,3,2,1)
+        expr = cp.Variable(shape=in_shape)[axis]
+        y = np.ones(in_shape)[axis]
+        prob = cp.Problem(self.obj, [expr == y])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, y)
+
+    @given(axis=arrays(shape=(2,2,2), dtype=bool))
+    def test_nd_bool_index(self, axis) -> None:
+        def is_zero_dim_output(axis):
+            return 0 in self.target[axis].shape
+
+        assume(is_zero_dim_output(axis) is False)
+        expr = self.x[axis]
+        y = self.target[axis]
+        prob = cp.Problem(self.obj, [expr == y])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, y)
+
+    def test_nd_index_sum(self) -> None:
+        expr = self.x[:,:,0].sum(axis=0)
+        y = self.target[:,:,0].sum(axis=0)
+        prob = cp.Problem(self.obj, [expr == y])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, y)
+
+    @pytest.mark.parametrize("order", ['C', 'F'])
+    @pytest.mark.parametrize("shape", [(20, 2, 30), (300, 2, 2),
+                                       (1, 24, 5, 10), (240, 5, 1)])
+    def test_nd_reshape(self, order, shape) -> None:
+        var = cp.Variable((5, 24, 10))
+        target = np.arange(1200).reshape((5, 24, 10))
+        expr = cp.reshape(var, shape, order=order)
+        y = target.reshape(shape, order=order)
+        prob = cp.Problem(self.obj, [expr == y])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, y)
+
+    def test_nd_transpose(self) -> None:
+        var = cp.Variable((5, 24, 10))
+        target = np.arange(1200).reshape((5, 24, 10))
+        expr = var.T
+        y = target.T
+        prob = cp.Problem(self.obj, [expr == y])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(expr.value, y)
+
+    @pytest.mark.parametrize("shapes", [((3),(253, 253, 3)),
+                                        ((7, 1, 5),(8, 7, 6, 5)),
+                                        ((1),(5, 4)),
+                                        ((4),(5, 4)),
+                                        ((15, 1, 5), (15, 3, 5)),
+                                        ((3, 5), (15, 3, 5)),
+                                        ((3, 1), (15, 3, 5))])
+    def test_nd_broadcast(self, shapes) -> None:
+        x = cp.Variable(shapes[0])
+        y = cp.broadcast_to(x, shape=shapes[1])
+        assert y.shape == shapes[1]
+        prob = cp.Problem(cp.Minimize(cp.sum(y)), [y == 1])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(y.value, 1)
+
+    @pytest.mark.parametrize("shapes", [((3), (2, 2, 2)),
+                                        ((3), (4)),
+                                        ((2, 1),(8, 4, 3))])
+    def test_nd_broadcast_error(self, shapes) -> None:
+        error_str = "operands could not be broadcast together"
+        with pytest.raises(Exception, match=error_str):
+            x = cp.Variable(shapes[0])
+            y = cp.broadcast_to(x, shape=shapes[1])
+            assert y.shape is not shapes[1]
+
+    @pytest.mark.parametrize("shapes", [((5),(3, 1)),
+                                        ((15, 1),(8)),
+                                        ((3), (2, 1))])
+    def test_no_segfault_multiply(self, shapes) -> None:
+        """
+        This test ensures that no error is raised when
+        multiplying two broadcastable array shapes <= 2.
+        Previously this would cause a segfault in the CPP backend.
+        """
+        x = cp.Variable(shapes[0])
+        target = np.arange(np.prod(shapes[0])).reshape(shapes[0])
+        a = np.arange(np.prod(shapes[1])).reshape(shapes[1])
+        b = np.arange(np.prod(shapes[1])).reshape(shapes[1])
+        obj = cp.sum(cp.max(cp.multiply(a, x) + b, axis=0))
+        prob = cp.Problem(cp.Minimize(obj), [x == target])
+        prob.solve()
+        assert np.allclose(x.value, target)
+
+    @pytest.mark.parametrize("shapes", [((3),(252, 253, 3)),
+                                        ((7, 1, 5),(8, 7, 6, 5)),
+                                        ((2, 1, 2), (2, 3, 2)),
+                                        ((15, 1, 5), (15, 3, 5)),
+                                        ((3, 5), (15, 3, 5)),
+                                        ((3, 1), (15, 3, 5))])
+    def test_nd_multiply_broadcast(self, shapes) -> None:
+        x = cp.Variable(shapes[0])
+        y = np.arange(np.prod(shapes[1])).reshape(shapes[1])
+        expr = cp.multiply(x, y)
+        target = np.arange(np.prod(shapes[0])).reshape(shapes[0])
+        prob = cp.Problem(cp.Minimize(cp.sum(expr)), [expr == target * y])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(x.value, target)
+
+    @pytest.mark.parametrize("shapes", [((3),(252, 253, 3)),
+                                        ((7, 1, 5),(8, 7, 6, 5)),
+                                        ((2, 1, 2), (2, 3, 2)),
+                                        ((3, 1), (15, 3, 5))])
+    def test_nd_add_broadcast(self, shapes) -> None:
+        x = cp.Variable(shapes[0])
+        y = np.arange(np.prod(shapes[1])).reshape(shapes[1])
+        expr = x + y
+        target = np.arange(np.prod(shapes[0])).reshape(shapes[0])
+        prob = cp.Problem(cp.Minimize(cp.sum(expr)), [expr == target + y])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(x.value, target)
+
+    @given(shape=broadcastable_shapes((8, 14, 8, 28), max_dims=4))
+    def test_nd_broadcast_generated(self, shape) -> None:
+        x = cp.Variable((8, 14, 8, 28))
+        y = np.arange(np.prod((shape))).reshape((shape))
+        expr = x - y
+        target = np.arange(np.prod((8,14,8,28))).reshape(8,14,8,28)
+        prob = cp.Problem(cp.Minimize(cp.sum(expr)), [expr == target - y])
+        prob.solve(canon_backend=cp.SCIPY_CANON_BACKEND)
+        assert np.allclose(x.value, target)
